package org.apache.bcel.classfile;

import java.io.DataInput;
import java.io.DataOutputStream;
import java.io.IOException;
import java.util.Arrays;
import org.apache.commons.lang3.ArrayUtils;

/* loaded from: org_apache_bcel_classfile.jar:org/apache/bcel/classfile/ExceptionTable.class */
public final class ExceptionTable extends Attribute {
    private int[] exceptionIndexTable;

    public ExceptionTable(ExceptionTable c) {
        this(c.getNameIndex(), c.getLength(), c.getExceptionIndexTable(), c.getConstantPool());
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public ExceptionTable(int nameIndex, int length, DataInput input, ConstantPool constantPool) throws IOException {
        this(nameIndex, length, (int[]) null, constantPool);
        int exceptionCount = input.readUnsignedShort();
        this.exceptionIndexTable = new int[exceptionCount];
        for (int i = 0; i < exceptionCount; i++) {
            this.exceptionIndexTable[i] = input.readUnsignedShort();
        }
    }

    public ExceptionTable(int nameIndex, int length, int[] exceptionIndexTable, ConstantPool constantPool) {
        super((byte) 3, nameIndex, length, constantPool);
        this.exceptionIndexTable = exceptionIndexTable != null ? exceptionIndexTable : ArrayUtils.EMPTY_INT_ARRAY;
    }

    @Override // org.apache.bcel.classfile.Attribute, org.apache.bcel.classfile.Node
    public void accept(Visitor v) {
        v.visitExceptionTable(this);
    }

    @Override // org.apache.bcel.classfile.Attribute
    public Attribute copy(ConstantPool constantPool) {
        ExceptionTable c = (ExceptionTable) clone();
        if (this.exceptionIndexTable != null) {
            c.exceptionIndexTable = (int[]) this.exceptionIndexTable.clone();
        }
        c.setConstantPool(constantPool);
        return c;
    }

    @Override // org.apache.bcel.classfile.Attribute
    public void dump(DataOutputStream file) throws IOException {
        super.dump(file);
        file.writeShort(this.exceptionIndexTable.length);
        for (int index : this.exceptionIndexTable) {
            file.writeShort(index);
        }
    }

    public int[] getExceptionIndexTable() {
        return this.exceptionIndexTable;
    }

    public String[] getExceptionNames() {
        String[] names = new String[this.exceptionIndexTable.length];
        Arrays.setAll(names, i -> {
            return Utility.pathToPackage(super.getConstantPool().getConstantString(this.exceptionIndexTable[i], (byte) 7));
        });
        return names;
    }

    public int getNumberOfExceptions() {
        if (this.exceptionIndexTable == null) {
            return 0;
        }
        return this.exceptionIndexTable.length;
    }

    public void setExceptionIndexTable(int[] exceptionIndexTable) {
        this.exceptionIndexTable = exceptionIndexTable != null ? exceptionIndexTable : ArrayUtils.EMPTY_INT_ARRAY;
    }

    @Override // org.apache.bcel.classfile.Attribute
    public String toString() {
        StringBuilder buf = new StringBuilder();
        buf.append("Exceptions: ");
        for (int i = 0; i < this.exceptionIndexTable.length; i++) {
            String str = super.getConstantPool().getConstantString(this.exceptionIndexTable[i], (byte) 7);
            buf.append(Utility.compactClassName(str, false));
            if (i < this.exceptionIndexTable.length - 1) {
                buf.append(", ");
            }
        }
        return buf.toString();
    }
}
